References
==========
.. automodule:: pykeen.models.unimodal
.. automodule:: pykeen.models.multimodal

.. [ali2020a] Ali, M., *et al.* (2020). `Bringing Light Into the Dark: A Large-scale Evaluation of Knowledge
   Graph Embedding Models Under a Unified Framework <http://arxiv.org/abs/2006.13365>`_. *arXiv*, 2006.13365.

.. [safavi2020] Safavi, T. & Koutra, D. (2020). `CoDEx: A Comprehensive Knowledge Graph
   Completion Benchmark <http://arxiv.org/abs/2009.07810>`_.  *arXiv*, 2009.07810.

.. [shi2017b] Shi, B., & Weninger, T. (2017). `Open-World Knowledge Graph Completion
   <https://arxiv.org/abs/1711.03438>`_. *arXiv*, 1957–1964.

.. [santos2020] Santos, A., *et al* (2020). `Clinical Knowledge Graph Integrates Proteomics Data into Clinical
   Decision-Making <https://doi.org/10.1101/2020.05.09.084897>`_. *bioRxiv*, 2020.05.09.084897.

.. [speer2017] Robyn Speer, Joshua Chin, and Catherine Havasi. (2017)
   `ConceptNet 5.5: An Open Multilingual Graph of General Knowledge <https://arxiv.org/abs/1612.03975>`_.
   *In proceedings of AAAI 31*.

.. [breit2020] Breit, A., *et al* (2020). `OpenBioLink: A benchmarking framework for large-scale biomedical link
   prediction <https://doi.org/10.1093/bioinformatics/btaa274>`_, *Bioinformatics*

.. [ilievski2020] Ilievski, F., Szekely, P., & Zhang, B. (2020). `CSKG: The CommonSense Knowledge
   Graph <http://arxiv.org/abs/2012.11490>`_. *arxiv*, 2012.11490.

.. [himmelstein2017] Himmelstein, D. S., *et al* (2017). `Systematic integration of biomedical knowledge
   prioritizes drugs for repurposing <https://doi.org/10.7554/eLife.26726>`_. ELife, 6.

.. [xu2019] Xu, L (2019) `A Comparison of Learned and Engineered Features in Network-Based Drug Repositioning
   <https://github.com/lingling93/master_thesis_drugrelink>`_. Master's Thesis.

.. [santurkar2018] Santurkar, S., *et al*. (2018). `How does batch normalization help optimization?
   <https://arxiv.org/abs/1805.11604>`_. Advances in Neural Information Processing Systems.

.. [chao2020] Chao, L., He, J., Wang, T., & Chu, W. (2020). `PairRE: Knowledge Graph Embeddings
   via Paired Relation Vectors <http://arxiv.org/abs/2011.03798>`_.

.. [ding2018] Ding, B., Wang, Q., Wang, B., & Guo, L. (2018). `Improving Knowledge Graph Embedding Using Simple
   Constraints <http://arxiv.org/abs/1805.02408>`_.

.. [balazevic2019b] Balažević, I., Allen, C., & Hospedales, T. (2019). `Multi-relational Poincaré Graph
   Embeddings <http://arxiv.org/abs/1905.09791>`_.

.. [fuhr2018] Fuhr, N. (2018). `Some Common Mistakes In IR Evaluation, And How They Can Be Avoided
   <https://doi.org/10.1145/3190580.3190586>`_. SIGIR Forum, 51(3), 32–41.

.. [sakai2021] Sakai, T. (2021). `On Fuhr's Guideline for IR Evaluation
   <https://doi.org/10.1145/3451964.3451976>`_. SIGIR Forum, 54(1), 1-8.

.. [galkin2020] Galkin, M., *et al.* (2020). `Message Passing for Hyper-Relational Knowledge Graphs
   <https://doi.org/10.18653/v1/2020.emnlp-main.596>`_. Proceedings of the 2020 Conference on Empirical
   Methods in Natural Language Processing (EMNLP), 7346–7359.

.. [wang2019] Wang, X., *et al* (2019). `KEPLER: A Unified Model for Knowledge Embedding and Pre-trained Language
   Representation <https://arxiv.org/pdf/1911.06136.pdf>`_. *arXiv*, 1911.06136.

.. [sun2018] Sun, Z., *et al.* (2018). `Bootstrapping Entity Alignment with Knowledge Graph Embedding.
   <https://dl.acm.org/doi/10.5555/3304222.3304381>`_
   *Proceedings of the 27th International Joint Conference on Artificial Intelligence*, 4396–4402.

.. [lin2018] Lin, T.-Y., *et al*. (2017). `Focal Loss for Dense Object Detection
   <https://doi.org/10.1109/TPAMI.2018.2858826>`_. *IEEE Transactions on Pattern Analysis and Machine
   Intelligence*, 42(2), 318–327.

.. [mukhoti2020] Mukhoti, J., *et al*. (2020). `Calibrating Deep Neural Networks using Focal Loss
   <http://arxiv.org/abs/2002.09437>`_.

.. [walsh2020] Walsh, B., *et al*. (2020). `BioKG: A Knowledge Graph for Relational Learning On Biological Data
   <https://doi.org/10.1145/3340531.3412776>`_. *Proceedings of the 29th ACM International Conference on Information &
   Knowledge Management*, 3173–3180.

.. [nickel2016review] Nickel, M., *et al*. (2016). `A Review of Relational Machine Learning for Knowledge Graphs
   <https://doi.org/10.1109/JPROC.2015.2483592>`_. *Proceedings of the IEEE*, 104(1), 11–33.

.. [ruffinelli2020] Ruffinelli, D., Broscheit, S., & Gemulla, R. (2020). `You CAN Teach an Old Dog New Tricks! On
   Training Knowledge Graph Embeddings <https://openreview.net/forum?id=BkxSmlBFvr>`_. *International Conference on
   Learning Representations*.

.. [zhang2017] Zhang, H., *et al*. (2017). `Visual Translation Embedding Network for Visual Relation
   Detection <http://arxiv.org/abs/1702.08319>`_. *arXiv*, 1702.08319.

.. [sharifzadeh2019vrd] Sharifzadeh, S., *et al*. (2019). `Improving Visual Relation Detection using Depth
   Maps <http://arxiv.org/abs/1905.00966>`_. *arXiv*, 1905.00966.

.. [gal2016] Gal, Y., & Ghahramani, Z. (2016). `Dropout as a Bayesian Approximation: Representing Model Uncertainty in
   Deep Learning <https://dl.acm.org/doi/10.5555/3045390.3045502>`_. *ICML 2016*.

.. [zhang2020] Zhang, Y., *et al.* (2020). `AutoSF: Searching Scoring Functions for Knowledge Graph Embedding
    <https://doi.org/10.1109/ICDE48307.2020.00044>`_. *ICDE 2020*, 433–444.

.. [tucker1966] Tucker, Ledyard R. (1966). `Some mathematical notes on three-mode factor analysis
    <https://dx.doi.org/10.1007/BF02289464>`_. *Psychometrika volume 31*, 279–311.

.. [ali2021] Ali, M., *et al* (2021). `Improving Inductive Link Prediction Using Hyper-relational
    Facts <https://arxiv.org/pdf/2107.04894>`_. *ISWC 2021*

.. [teru2020] Teru, K., *et al* (2020). `Inductive Relation Prediction by Subgraph Reasoning
   <https://arxiv.org/abs/1911.06962>`_. *ICML 2020*

.. [zheng2020] Zheng, S., *et al* (2020). `PharmKG: a dedicated knowledge graph benchmark for biomedical data mining
   <https://doi.org/10.1093/bib/bbaa344>`_. *Briefings in Bioinformatics 2020*

.. [berrendorf2020] Berrendorf, M., *et al.* (2020). `On the Ambiguity of Rank-Based Evaluation of Entity Alignment
   or Link Prediction Methods <http://arxiv.org/abs/2002.06914>`_.

.. [yu2021] Yu, L., *et al* (2021). `TripleRE: Knowledge Graph Embeddings via triple Relation Vectors
   <https://vixra.org/abs/2112.0095>`_. *viXra*, 2112.0095.
